@@ -78,21 +78,13 @@ ST_FUNC void asm_global_instr(void)
 #endif
 
 /********************************************************/
-
 #ifdef _WIN32
-// GCC appears to use '/' for relative paths and '\\' for absolute paths on Windows
 static char *normalize_slashes(char *path)
 {
     char *p;
-    if (path[1] == ':') {
-        for (p = path+2; *p; ++p)
-            if (*p == '/')
-                *p = '\\';
-    } else {
-        for (p = path; *p; ++p)
-            if (*p == '\\')
-                *p = '/';
-    }
+    for (p = path; *p; ++p)
+        if (*p == '\\')
+            *p = '/';
     return path;
 }
 
@@ -997,8 +989,6 @@ LIBTCCAPI TCCState *tcc_new(void)
     /* glibc defines */
     tcc_define_symbol(s, "__REDIRECT(name, proto, alias)", "name proto __asm__ (#alias)");
     tcc_define_symbol(s, "__REDIRECT_NTH(name, proto, alias)", "name proto __asm__ (#alias) __THROW");
-    /* default library paths */
-    tcc_add_library_path(s, CONFIG_TCC_LIBPATHS);
     /* paths for crt objects */
     tcc_split_path(s, (void ***)&s->crt_paths, &s->nb_crt_paths, CONFIG_TCC_CRTPREFIX);
 #endif
@@ -1036,6 +1026,7 @@ LIBTCCAPI TCCState *tcc_new(void)
 #ifdef TCC_TARGET_I386
     s->seg_size = 32;
 #endif
+    s->runtime_main = "main";
     return s;
 }
 
@@ -1350,8 +1341,8 @@ LIBTCCAPI int tcc_set_output_type(TCCState *s, int output_type)
         put_stabs("", 0, 0, 0, 0);
     }
 
-#ifdef TCC_TARGET_PE
     tcc_add_library_path(s, CONFIG_TCC_LIBPATHS);
+#ifdef TCC_TARGET_PE
 # ifdef _WIN32
     tcc_add_systemdir(s);
 # endif
