@@ -168,10 +168,13 @@
 #ifndef CONFIG_LDDIR
 # define CONFIG_LDDIR "lib"
 #endif
+#ifndef CONFIG_MULTIARCHDIR
+#define CONFIG_MULTIARCHDIR
+#endif
 
 /* path to find crt1.o, crti.o and crtn.o */
 #ifndef CONFIG_TCC_CRTPREFIX
-# define CONFIG_TCC_CRTPREFIX CONFIG_SYSROOT "/usr/" CONFIG_LDDIR
+# define CONFIG_TCC_CRTPREFIX CONFIG_SYSROOT "/usr/" CONFIG_LDDIR "/" CONFIG_MULTIARCHDIR
 #endif
 
 /* Below: {B} is substituted by CONFIG_TCCDIR (rsp. -B option) */
@@ -180,16 +183,11 @@
 #ifndef CONFIG_TCC_SYSINCLUDEPATHS
 # ifdef TCC_TARGET_PE
 #  define CONFIG_TCC_SYSINCLUDEPATHS "{B}/include;{B}/include/winapi"
-# elif defined CONFIG_MULTIARCHDIR
-#  define CONFIG_TCC_SYSINCLUDEPATHS \
-        CONFIG_SYSROOT "/usr/local/include" \
-    ":" CONFIG_SYSROOT "/usr/local/include/" CONFIG_MULTIARCHDIR \
-    ":" CONFIG_SYSROOT "/usr/include" \
-    ":" CONFIG_SYSROOT "/usr/include/" CONFIG_MULTIARCHDIR \
-    ":" "{B}/include"
 # else
 #  define CONFIG_TCC_SYSINCLUDEPATHS \
-        CONFIG_SYSROOT "/usr/local/include" \
+        CONFIG_SYSROOT "/usr/local/include/" CONFIG_MULTIARCHDIR \
+    ":" CONFIG_SYSROOT "/usr/local/include" \
+    ":" CONFIG_SYSROOT "/usr/include/" CONFIG_MULTIARCHDIR \
     ":" CONFIG_SYSROOT "/usr/include" \
     ":" "{B}/include"
 # endif
@@ -201,8 +199,11 @@
 #  define CONFIG_TCC_LIBPATHS "{B}/lib;{B}"
 # else
 #  define CONFIG_TCC_LIBPATHS \
-        CONFIG_SYSROOT "/usr/" CONFIG_LDDIR \
+        CONFIG_SYSROOT "/usr/" CONFIG_LDDIR "/" CONFIG_MULTIARCHDIR \
+    ":" CONFIG_SYSROOT "/usr/" CONFIG_LDDIR \
+    ":" CONFIG_SYSROOT "/" CONFIG_LDDIR "/" CONFIG_MULTIARCHDIR \
     ":" CONFIG_SYSROOT "/" CONFIG_LDDIR \
+    ":" CONFIG_SYSROOT "/usr/local/" CONFIG_LDDIR "/" CONFIG_MULTIARCHDIR \
     ":" CONFIG_SYSROOT "/usr/local/" CONFIG_LDDIR
 # endif
 #endif
@@ -235,7 +236,7 @@
 #endif
 
 /* library to use with CONFIG_USE_LIBGCC instead of libtcc1.a */
-#define TCC_LIBGCC CONFIG_SYSROOT "/" CONFIG_LDDIR "/libgcc_s.so.1"
+#define TCC_LIBGCC CONFIG_SYSROOT "/" CONFIG_LDDIR "/" CONFIG_MULTIARCHDIR "/libgcc_s.so.1"
 
 /* -------------------------------------------- */
 /* include the target specific definitions */
@@ -388,9 +389,10 @@ typedef struct AttributeDef {
       func_export   : 1,
       func_import   : 1,
       func_args     : 5,
+      func_proto    : 1,
       mode          : 4,
       weak          : 1,
-      fill          : 11;
+      fill          : 10;
     struct Section *section;
     int alias_target;    /* token */
 } AttributeDef;
@@ -400,6 +402,7 @@ typedef struct AttributeDef {
 #define FUNC_EXPORT(r) (((AttributeDef*)&(r))->func_export)
 #define FUNC_IMPORT(r) (((AttributeDef*)&(r))->func_import)
 #define FUNC_ARGS(r) (((AttributeDef*)&(r))->func_args)
+#define FUNC_PROTO(r) (((AttributeDef*)&(r))->func_proto)
 #define FUNC_ALIGN(r) (((AttributeDef*)&(r))->aligned)
 #define FUNC_PACKED(r) (((AttributeDef*)&(r))->packed)
 #define ATTR_MODE(r)  (((AttributeDef*)&(r))->mode)
@@ -665,6 +668,7 @@ struct TCCState {
 #endif
 
 #ifdef TCC_IS_NATIVE
+    const char *runtime_main;
     /* for tcc_relocate */
     void *runtime_mem;
 # ifdef HAVE_SELINUX
@@ -749,8 +753,9 @@ struct TCCState {
 #define VT_IMPORT  0x00004000  /* win32: extern data imported from dll */
 #define VT_EXPORT  0x00008000  /* win32: data exported from dll */
 #define VT_WEAK    0x00010000  /* weak symbol */
+#define VT_TLS     0x00040000  /* thread-local storage */
 
-#define VT_STRUCT_SHIFT 18     /* shift for bitfield shift values (max: 32 - 2*6) */
+#define VT_STRUCT_SHIFT 19     /* shift for bitfield shift values (max: 32 - 2*6) */
 
 /* type mask (except storage) */
 #define VT_STORAGE (VT_EXTERN | VT_STATIC | VT_TYPEDEF | VT_INLINE | VT_IMPORT | VT_EXPORT | VT_WEAK)
@@ -1136,6 +1141,7 @@ ST_FUNC void expect(const char *msg);
 /* ------------ tccgen.c ------------ */
 
 ST_DATA Section *text_section, *data_section, *bss_section; /* predefined sections */
+ST_DATA Section *tdata_section, *tbss_section; /* thread-local storage sections */
 ST_DATA Section *cur_text_section; /* current section where function code is generated */
 #ifdef CONFIG_TCC_ASM
 ST_DATA Section *last_text_section; /* to handle .previous asm directive */
